@@ -1,9 +1,9 @@
-from typing import Tuple, Iterable, Union
+from typing import Iterable, Tuple, Union
 
 from bip32 import BIP32, HARDENED_INDEX
 from mnemonic import Mnemonic
 
-from bip44.consts import COIN_PATHS, coin_path_by_index
+from .consts import COIN_PATHS, coin_path_by_index
 
 __all__ = ("Wallet",)
 
@@ -17,7 +17,6 @@ class Wallet:
         :param language (str, optional): The mnemonic's language, default: "english"
         :param passphrase (str, optional): The mnemonic's passphrase, default: ""
         """
-        self._mnemonic = mnemonic
         self._seed = Mnemonic(language).to_seed(mnemonic, passphrase)
         self._bip32 = BIP32.from_seed(self._seed)
 
